# molecularprofiles

!! OBSOLETE !! 
Will be updated upon availability of CI configuration

See the documentation here: https://molecularprofiles.readthedocs.io/en/latest/

functions to plot and work with meteorological data in grib2 format from ECMWF and GDAS. This work is used for the calibration of the CTA

https://github.com/cambecc/grib2json

In order to install it go to the directory containing the file setup.py and type:

pip install ./


